# build_result_spec.rb
# Copyright 2013 Doug Ireton

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

require 'json'
require 'spec_helper'

describe StashNotifier::BuildResult do

  let(:args) {
    {
      state: 'successful',
      key: 'repo-master',
      name: 'repo-master-42',
      url: 'https://gittst.example.com',
      description: 'This is the description'
    }
  }

  let(:build_result)  { StashNotifier::BuildResult.new(args) }

  describe '#state' do
    it "returns UPPERCASE state" do
      expect(build_result.state).to eq('SUCCESSFUL')
    end

    it 'accepts a different state' do
      build_result.state = 'failed'
      expect(build_result.state).to eq('FAILED')
    end

    it 'raises an ArgumentError when state is not valid' do
      expect { build_result.state = 'foo' }.to raise_error(ArgumentError)
    end
  end

  describe '#key' do
    it 'returns the build key' do
      expect(build_result.key).to eq 'repo-master'
    end
  end

  describe '#name' do
    it 'returns the name' do
      expect(build_result.name).to eq 'repo-master-42'
    end
  end

  describe '#url' do
    it 'returns the url' do
      expect(build_result.url).to eq 'https://gittst.example.com'
    end
  end

  describe '#description' do
    it 'returns the description' do
      expect(build_result.description).to eq 'This is the description'
    end
  end

  describe '#to_json' do
    it 'returns a JSON string suitable for sending to the Stash Build Result API endpoint' do
      args[:state] = 'SUCCESSFUL'
      expect(build_result.to_json).to eq(args.to_json)
    end
  end

end
